@@ -19,7 +19,9 @@ under the License.
 """
 from __future__ import with_statement
 
-import urllib, re, csv
+import urllib
+import re
+import csv
 from cStringIO import StringIO
 import httplib
 import socket
@@ -37,13 +39,16 @@ from riak.riak_index_entry import RiakIndexEntry
 from riak.multidict import MultiDict
 from connection import HTTPConnectionManager
 import riak.util
+from xml.etree import ElementTree
 
-MAX_LINK_HEADER_SIZE = 8192 - 8 # substract length of "Link: " header string and newline
+# subtract length of "Link: " header string and newline
+MAX_LINK_HEADER_SIZE = 8192 - 8
 
-class RiakHttpTransport(RiakTransport) :
+
+class RiakHttpTransport(RiakTransport):
     """
-    The RiakHttpTransport object holds information necessary to connect to
-    Riak. The Riak API uses HTTP, so there is no persistent
+    The RiakHttpTransport object holds information necessary to
+    connect to Riak. The Riak API uses HTTP, so there is no persistent
     connection, and the RiakClient object is extremely lightweight.
     """
 
@@ -88,19 +93,57 @@ class RiakHttpTransport(RiakTransport) :
     def get_client_id(self):
         return self._client_id
 
-    def ping(self) :
+    def ping(self):
         """
         Check server is alive over HTTP
         """
         response = self.http_request('GET', '/ping')
         return(response is not None) and (response[1] == 'OK')
 
+    def stats(self):
+        """
+        Gets performance statistics and server information
+        """
+        # TODO: use resource detection
+        response = self.http_request('GET', '/stats',
+                                     {'Accept': 'application/json'})
+        if response[0]['http_code'] is 200:
+            return json.loads(response[1])
+        else:
+            return None
 
-    def get(self, robj, r = None, pr = None, vtag = None) :
+    # FeatureDetection API - private
+    def _server_version(self):
+        stats = self.stats()
+        if stats is not None:
+            return stats['riak_kv_version']
+        # If stats is disabled, we can't assume the Riak version
+        # is >= 1.1. However, we can assume the new URL scheme is
+        # at least version 1.0
+        elif 'riak_kv_wm_buckets' in self.get_resources():
+            return "1.0.0"
+        else:
+            return "0.14.0"
+
+    def get_resources(self):
+        """
+        Gets a JSON mapping of server-side resource names to paths
+        :rtype dict
+        """
+        response = self.http_request('GET', '/',
+                                     {'Accept': 'application/json'})
+        if response[0]['http_code'] is 200:
+            return json.loads(response[1])
+        else:
+            return {}
+
+    def get(self, robj, r=None, pr=None, vtag=None):
         """
         Get a bucket/key from the server
         """
-        params = {'r' : r, 'pr': pr}
+        # We could detect quorum_controls here but HTTP ignores
+        # unknown flags/params.
+        params = {'r': r, 'pr': pr}
         if vtag is not None:
             params['vtag'] = vtag
         url = self.build_rest_path(robj.get_bucket(), robj.get_key(),
@@ -108,45 +151,57 @@ class RiakHttpTransport(RiakTransport) :
         response = self.http_request('GET', url)
         return self.parse_body(response, [200, 300, 404])
 
-    def put(self, robj, w = None, dw = None, pw = None, return_body = True, if_none_match=False):
+    def put(self, robj, w=None, dw=None, pw=None, return_body=True,
+            if_none_match=False):
         """
         Serialize put request and deserialize response
         """
-       # Construct the URL...
-        params = {'returnbody' : str(return_body).lower(), 'w' : w, 'dw' : dw, 'pw' : pw }
-        url = self.build_rest_path(bucket=robj.get_bucket(), key=robj.get_key(),
+        # We could detect quorum_controls here but HTTP ignores
+        # unknown flags/params.
+        params = {'returnbody': str(return_body).lower(),
+                  'w': w, 'dw': dw, 'pw': pw}
+        url = self.build_rest_path(bucket=robj.get_bucket(),
+                                   key=robj.get_key(),
                                    params=params)
         headers = self.build_put_headers(robj)
+        # TODO: use a more general 'prevent_stale_writes' semantics,
+        # which is a superset of the if_none_match semantics.
         if if_none_match:
             headers["If-None-Match"] = "*"
         content = robj.get_encoded_data()
-        return self.do_put(url, headers, content, return_body, key=robj.get_key())
+        return self.do_put(url, headers, content, return_body,
+                           key=robj.get_key())
 
     def do_put(self, url, headers, content, return_body=False, key=None):
         if key is None:
-          response = self.http_request('POST', url, headers, content)
+            response = self.http_request('POST', url, headers, content)
         else:
-          response = self.http_request('PUT', url, headers, content)
+            response = self.http_request('PUT', url, headers, content)
 
         if return_body:
-          return self.parse_body(response, [200, 201, 300])
+            return self.parse_body(response, [200, 201, 300])
         else:
-          self.check_http_code(response, [204])
-          return None
+            self.check_http_code(response, [204])
+            return None
 
-    def put_new(self, robj, w=None, dw=None, pw=None, return_body=True, if_none_match=False):
+    def put_new(self, robj, w=None, dw=None, pw=None, return_body=True,
+                if_none_match=False):
         """Put a new object into the Riak store, returning its (new) key."""
-        # Construct the URL...
-        params = {'returnbody' : str(return_body).lower(), 'w' : w, 'dw' : dw, 'pw' : pw}
+        # We could detect quorum_controls here but HTTP ignores
+        # unknown flags/params.
+        params = {'returnbody': str(return_body).lower(), 'w': w, 'dw': dw,
+                  'pw': pw}
         url = self.build_rest_path(bucket=robj.get_bucket(), params=params)
         headers = self.build_put_headers(robj)
+        # TODO: use a more general 'prevent_stale_writes' semantics,
+        # which is a superset of the if_none_match semantics.
         if if_none_match:
             headers["If-None-Match"] = "*"
         content = robj.get_encoded_data()
         response = self.http_request('POST', url, headers, content)
         location = response[0]['location']
         idx = location.rindex('/')
-        key = location[idx+1:]
+        key = location[(idx + 1):]
         if return_body:
             vclock, [(metadata, data)] = self.parse_body(response, [201])
             return key, vclock, metadata
@@ -154,20 +209,27 @@ class RiakHttpTransport(RiakTransport) :
             self.check_http_code(response, [201])
             return key, None, None
 
-    def delete(self, robj, rw=None, r = None, w = None, dw = None, pr = None, pw = None):
-        # Construct the URL...
-        params = {'rw' : rw, 'r': r, 'w': w, 'dw': dw, 'pr': pr, 'pw': pw}
+    def delete(self, robj, rw=None, r=None, w=None, dw=None, pr=None, pw=None):
+        """
+        Delete an object.
+        """
+        # We could detect quorum_controls here but HTTP ignores
+        # unknown flags/params.
+        params = {'rw': rw, 'r': r, 'w': w, 'dw': dw, 'pr': pr, 'pw': pw}
+        headers = {}
         url = self.build_rest_path(robj.get_bucket(), robj.get_key(),
                                    params=params)
-        # TODO: Send vclock of robj if it exists
-        # Run the operation..
-        response = self.http_request('DELETE', url)
+        if self.tombstone_vclocks() and robj.vclock() is not None:
+            headers['X-Riak-Vclock'] = robj.vclock()
+        response = self.http_request('DELETE', url, headers)
         self.check_http_code(response, [204, 404])
         return self
 
-
     def get_keys(self, bucket):
-        params = {'props' : 'True', 'keys' : 'true'}
+        """
+        Fetch a list of keys for the bucket
+        """
+        params = {'props': 'True', 'keys': 'true'}
         url = self.build_rest_path(bucket, params=params)
         response = self.http_request('GET', url)
 
@@ -179,6 +241,9 @@ class RiakHttpTransport(RiakTransport) :
             raise Exception('Error getting bucket properties.')
 
     def get_buckets(self):
+        """
+        Fetch a list of all buckets
+        """
         params = {'buckets': 'true'}
         url = self.build_rest_path(None, params=params)
         response = self.http_request('GET', url)
@@ -191,8 +256,11 @@ class RiakHttpTransport(RiakTransport) :
             raise Exception('Error getting buckets.')
 
     def get_bucket_props(self, bucket):
+        """
+        Get properties for a bucket
+        """
         # Run the request...
-        params = {'props' : 'True', 'keys' : 'False'}
+        params = {'props': 'true', 'keys': 'false'}
         url = self.build_rest_path(bucket, params=params)
         response = self.http_request('GET', url)
 
@@ -204,14 +272,13 @@ class RiakHttpTransport(RiakTransport) :
         else:
             raise Exception('Error getting bucket properties.')
 
-
     def set_bucket_props(self, bucket, props):
         """
         Set the properties on the bucket object given
         """
         url = self.build_rest_path(bucket)
-        headers = {'Content-Type' : 'application/json'}
-        content = json.dumps({'props' : props})
+        headers = {'Content-Type': 'application/json'}
+        content = json.dumps({'props': props})
 
         # Run the request...
         response = self.http_request('PUT', url, headers, content)
@@ -227,8 +294,15 @@ class RiakHttpTransport(RiakTransport) :
         return True
 
     def mapred(self, inputs, query, timeout=None):
+        """
+        Run a MapReduce query.
+        """
+        if not self.phaseless_mapred() and (query is None or len(query) is 0):
+            raise Exception(
+                'Phase-less MapReduce is not supported by Riak node')
+
         # Construct the job, optionally set the timeout...
-        job = {'inputs':inputs, 'query':query}
+        job = {'inputs': inputs, 'query': query}
         if timeout is not None:
             job['timeout'] = timeout
 
@@ -242,16 +316,57 @@ class RiakHttpTransport(RiakTransport) :
         # Make sure the expected status code came back...
         status = response[0]['http_code']
         if status != 200:
-            raise Exception('Error running MapReduce operation. Status: ' + str(status) + ' : ' + response[1])
+            raise Exception(
+                'Error running MapReduce operation. Headers: %s Body: %s' %
+                (repr(response[0]), repr(response[1])))
 
         result = json.loads(response[1])
         return result
 
+    def get_index(self, bucket, index, startkey, endkey=None):
+        """
+        Performs a secondary index query.
+        """
+        # TODO: use resource detection
+        segments = ["buckets", bucket, "index", index, str(startkey)]
+        if endkey:
+            segments.append(str(endkey))
+        uri = '/%s' % ('/'.join(segments))
+        headers, data = response = self.get_request(uri)
+        self.check_http_code(response, [200])
+        jsonData = json.loads(data)
+        return jsonData[u'keys'][:]
+
+    def search(self, index, query, **params):
+        """
+        Performs a search query.
+        """
+        if index is None:
+            index = 'search'
+
+        options = {'q': query, 'wt': 'json'}
+        if 'op' in params:
+            op = params.pop('op')
+            options['q.op'] = op
+
+        options.update(params)
+        # TODO: use resource detection
+        uri = "/solr/%s/select" % index
+        headers, data = response = self.get_request(uri, options)
+        self.check_http_code(response, [200])
+        if 'json' in headers['content-type']:
+            results = json.loads(data)
+            return self._normalize_json_search_response(results)
+        elif 'xml' in headers['content-type']:
+            return self._normalize_xml_search_response(data)
+        else:
+            raise ValueError("Could not decode search response")
+
     def check_http_code(self, response, expected_statuses):
         status = response[0]['http_code']
         if not status in expected_statuses:
-            m = 'Expected status ' + str(expected_statuses) + ', received ' + str(status) + ' : ' + response[1]
-            raise Exception(m)
+            raise Exception('Expected status %s, received %s : %s' %
+                            (expected_statuses, status, response[1]))
 
     def parse_body(self, response, expected_statuses):
         """
@@ -302,12 +417,13 @@ class RiakHttpTransport(RiakTransport) :
                 metadata[MD_CTYPE] = value
             elif header == 'etag':
                 metadata[MD_VTAG] = value
-            elif header =='link':
+            elif header == 'link':
                 self.parse_links(links, headers['link'])
             elif header == 'last-modified':
                 metadata[MD_LASTMOD] = value
             elif header.startswith('x-riak-meta-'):
-                metadata[MD_USERMETA][header.replace('x-riak-meta-', '')] = value
+                metakey = header.replace('x-riak-meta-', '')
+                metadata[MD_USERMETA][metakey] = value
             elif header.startswith('x-riak-index-'):
                 field = header.replace('x-riak-index-', '')
                 reader = csv.reader([value], skipinitialspace=True)
@@ -315,9 +431,10 @@ class RiakHttpTransport(RiakTransport) :
                     for token in line:
                         rie = RiakIndexEntry(field, token)
                         metadata[MD_INDEX].append(rie)
-
             elif header == 'x-riak-vclock':
                 vclock = value
+            elif header == 'x-riak-deleted':
+                metadata[MD_DELETED] = True
         if links:
             metadata[MD_LINKS] = links
 
@@ -340,10 +457,12 @@ class RiakHttpTransport(RiakTransport) :
         Private.
         @return self
         """
+        oldform = "</([^/]+)/([^/]+)/([^/]+)>; ?riaktag=\"([^\']+)\""
+        newform = "</(buckets)/([^/]+)/keys/([^/]+)>; ?riaktag=\"([^\']+)\""
         for linkHeader in linkHeaders.strip().split(','):
             linkHeader = linkHeader.strip()
-            matches = re.match("</([^/]+)/([^/]+)/([^/]+)>; ?riaktag=\"([^\']+)\"", linkHeader) or \
-                re.match("</(buckets)/([^/]+)/keys/([^/]+)>; ?riaktag=\"([^\']+)\"", linkHeader)
+            matches = (re.match(oldform, linkHeader) or
+                       re.match(newform, linkHeader))
             if matches is not None:
                 link = RiakLink(urllib.unquote_plus(matches.group(2)),
                                 urllib.unquote_plus(matches.group(3)),
@@ -361,7 +480,8 @@ class RiakHttpTransport(RiakTransport) :
                     headers.add('Link', current_header)
                     current_header = ''
 
-                if current_header != '': header = ', ' + header
+                if current_header != '':
+                    header = ', ' + header
                 current_header += header
 
             headers.add('Link', current_header)
@@ -372,10 +492,11 @@ class RiakHttpTransport(RiakTransport) :
         url = self.build_rest_path(bucket=None, params=params, prefix=uri)
         return self.http_request('GET', url)
 
-    def store_file(self, key, content_type="application/octet-stream", content=None):
+    def store_file(self, key, content_type="application/octet-stream",
+                   content=None):
         url = self.build_rest_path(prefix='luwak', key=key)
-        headers = {'Content-Type' : content_type,
-                   'X-Riak-ClientId' : self._client_id}
+        headers = {'Content-Type': content_type,
+                   'X-Riak-ClientId': self._client_id}
 
         return self.do_put(url, headers, content, key=key)
 
@@ -393,13 +514,15 @@ class RiakHttpTransport(RiakTransport) :
         response = self.http_request('DELETE', url)
         self.parse_body(response, [204, 404])
 
-    def post_request(self, uri=None, body=None, params=None, content_type="application/json"):
+    def post_request(self, uri=None, body=None, params=None,
+                     content_type="application/json"):
         uri = self.build_rest_path(prefix=uri, params=params)
-        return self.http_request('POST', uri, {'Content-Type': content_type}, body)
+        return self.http_request('POST', uri, {'Content-Type': content_type},
+                                 body)
 
     # Utility functions used by Riak library.
 
-    def build_rest_path(self, bucket=None, key=None, params=None, prefix=None) :
+    def build_rest_path(self, bucket=None, key=None, params=None, prefix=None):
         """
         Given a RiakClient, RiakBucket, Key, LinkSpec, and Params,
         construct and return a URL.
@@ -421,8 +544,10 @@ class RiakHttpTransport(RiakTransport) :
             s = ''
             for key in params.keys():
                 if params[key] is not None:
-                    if s != '': s += '&'
-                    s += urllib.quote_plus(key) + '=' + urllib.quote_plus(str(params[key]))
+                    if s != '':
+                        s += '&'
+                    s += (urllib.quote_plus(key) + '=' +
+                          urllib.quote_plus(str(params[key])))
             path += '?' + s
 
         # Return.
@@ -432,9 +557,9 @@ class RiakHttpTransport(RiakTransport) :
         """Build the headers for a POST/PUT request."""
 
         # Construct the headers...
-        headers = MultiDict({'Accept' : 'text/plain, */*; q=0.5',
-                             'Content-Type' : robj.get_content_type(),
-                             'X-Riak-ClientId' : self._client_id})
+        headers = MultiDict({'Accept': 'text/plain, */*; q=0.5',
+                             'Content-Type': robj.get_content_type(),
+                             'X-Riak-ClientId': self._client_id})
 
         # Add the vclock if it exists...
         if robj.vclock() is not None:
@@ -455,7 +580,7 @@ class RiakHttpTransport(RiakTransport) :
 
         return headers
 
-    def http_request(self, method, uri, headers=None, body='') :
+    def http_request(self, method, uri, headers=None, body=''):
         """
         Given a Method, URL, Headers, and Body, perform and HTTP request,
         and return a 2-tuple containing a dictionary of response headers
@@ -481,7 +606,7 @@ class RiakHttpTransport(RiakTransport) :
                         # Get the body...
                         response_body = response.read()
                     finally:
-                      response.close()
+                        response.close()
 
                     return response_headers, response_body
                 except socket.error, e:
@@ -499,12 +624,42 @@ class RiakHttpTransport(RiakTransport) :
         # No luck, even with retrying.
         raise RiakError("could not get a response")
 
-    @classmethod
-    def build_headers(cls, headers):
-        return ['%s: %s' % (header, value) for header, value in headers.iteritems()]
+    def _normalize_json_search_response(self, json):
+        """
+        Normalizes a JSON search response so that PB and HTTP have the
+        same return value
+        """
+        result = {}
+        if u'response' in json:
+            result['num_found'] = json[u'response'][u'numFound']
+            result['max_score'] = float(json[u'response'][u'maxScore'])
+            docs = []
+            for doc in json[u'response'][u'docs']:
+                resdoc = {u'id': doc[u'id']}
+                if u'fields' in doc:
+                    for k, v in doc[u'fields'].iteritems():
+                        resdoc[k] = v
+                docs.append(resdoc)
+            result['docs'] = docs
+        return result
+
+    def _normalize_xml_search_response(self, xml):
+        """
+        Normalizes an XML search response so that PB and HTTP have the
+        same return value
+        """
+        target = XMLSearchResult()
+        parser = ElementTree.XMLParser(target=target)
+        parser.feed(xml)
+        return parser.close()
 
     @classmethod
-    def parse_http_headers(cls, headers) :
+    def build_headers(cls, headers):
+        return ['%s: %s' % (header, value)
+                for header, value in headers.iteritems()]
+
+    @classmethod
+    def parse_http_headers(cls, headers):
         """
         Parse an HTTP Header string into an asssociative array of
         response headers.
@@ -513,7 +668,8 @@ class RiakHttpTransport(RiakTransport) :
         fields = headers.split("\n")
         for field in fields:
             matches = re.match("([^:]+):(.+)", field)
-            if matches is None: continue
+            if matches is None:
+                continue
             key = matches.group(1).lower()
             value = matches.group(2).strip()
             if key in retVal.keys():
@@ -524,3 +680,53 @@ class RiakHttpTransport(RiakTransport) :
             else:
                 retVal[key] = value
         return retVal
+
+
+class XMLSearchResult(object):
+    # Match tags that are document fields
+    fieldtags = ['str', 'int', 'date']
+
+    def __init__(self):
+        # Results
+        self.num_found = 0
+        self.max_score = 0.0
+        self.docs = []
+
+        # Parser state
+        self.currdoc = None
+        self.currfield = None
+        self.currvalue = None
+
+    def start(self, tag, attrib):
+        if tag == 'result':
+            self.num_found = int(attrib['numFound'])
+            self.max_score = float(attrib['maxScore'])
+        elif tag == 'doc':
+            self.currdoc = {}
+        elif tag in self.fieldtags and self.currdoc is not None:
+            self.currfield = attrib['name']
+
+    def end(self, tag):
+        if tag == 'doc' and self.currdoc is not None:
+            self.docs.append(self.currdoc)
+            self.currdoc = None
+        elif tag in self.fieldtags and self.currdoc is not None:
+            if tag == 'int':
+                self.currvalue = int(self.currvalue)
+            self.currdoc[self.currfield] = self.currvalue
+            self.currfield = None
+            self.currvalue = None
+
+    def data(self, data):
+        if self.currfield:
+            # riak_solr_output adds NL + 6 spaces
+            data = data.rstrip()
+            if self.currvalue:
+                self.currvalue += data
+            else:
+                self.currvalue = data
+
+    def close(self):
+        return {'num_found': self.num_found,
+                'max_score': self.max_score,
+                'docs': self.docs}
